==> xlr-application-pipelines-module-25.1.0-1024.113-sources.jar: com/xebialabs/xlrelease/status/service/script/ExternalDeploymentScriptExecutor.scala <==
package com.xebialabs.xlrelease.status.service.script

import com.xebialabs.xlrelease.runner.impl.RunnerScriptService
import com.xebialabs.xlrelease.script.XlrScriptContext
import com.xebialabs.xlrelease.script.jython.{JythonScriptService, XlrJythonSupport}
import com.xebialabs.xlrelease.status.service.script.ExternalDeploymentScriptExecutor._
import com.xebialabs.xlrelease.status.webhook.events.{DeploymentServerEvent, RemoteStatusWebhookEventSource, StatusWebhookEventSource}
import grizzled.slf4j.Logging
import io.micrometer.core.annotation.Timed
import org.springframework.stereotype.Component

trait ExternalDeploymentScriptService {
  @throws(classOf[Exception])
  def executeScript(eventSource: StatusWebhookEventSource): AnyRef
}

@Component
class ExternalDeploymentScriptExecutor(
                            val scriptService: JythonScriptService,
                            runnerScriptService: RunnerScriptService
                          ) extends XlrJythonSupport
  with ExternalDeploymentScriptService
  with Logging {

  @Timed
  @throws(classOf[Exception])
  override def executeScript(connection: StatusWebhookEventSource): AnyRef = {
    logger.debug(s"Executing status script for StatusWebhookEventSource ${connection.getName}")
    if (connection.isInstanceOf[RemoteStatusWebhookEventSource]) {
      runnerScriptService.executeScript[DeploymentServerEvent](
        connection.statusScript,
        buildDefaultInputParams(connection))
    } else {
      val scriptContext = createStatusScriptContext(connection)
      executeScript(scriptContext)
      scriptContext.getAttribute("data")
    }
  }
}

private class StatusScriptContextBuilder(connection: StatusWebhookEventSource) extends BaseScriptContextBuilder(connection) {

  override val scriptProperty: String = StatusScriptProperty

  override protected def doBuild(context: XlrScriptContext): Unit = {
    addConnectionAttributes(context)
    addConnectionServerAttributes(context)
    addScript(context)
  }
}

private object ExternalDeploymentScriptExecutor {
  def createStatusScriptContext(connection: StatusWebhookEventSource): XlrScriptContext = {
    new StatusScriptContextBuilder(connection).build()
  }
}

==> xlr-application-pipelines-module-25.3.0-808.945-sources.jar: com/xebialabs/xlrelease/status/service/script/ExternalDeploymentScriptExecutor.scala <==
package com.xebialabs.xlrelease.status.service.script

import com.xebialabs.xlrelease.runner.impl.RunnerScriptService
import com.xebialabs.xlrelease.script.XlrScriptContext
import com.xebialabs.xlrelease.script.jython.JythonScriptService
import com.xebialabs.xlrelease.status.service.script.ExternalDeploymentScriptExecutor.createStatusScriptContext
import com.xebialabs.xlrelease.status.webhook.events.{DeploymentServerEvent, RemoteStatusWebhookEventSource}
import com.xebialabs.xlrelease.webhooks.consumers.StatusWebhookEventSource
import grizzled.slf4j.Logging
import io.micrometer.core.annotation.Timed
import org.springframework.stereotype.Component

trait ExternalDeploymentScriptService {
  @throws(classOf[Exception])
  def executeScript(eventSource: StatusWebhookEventSource): AnyRef
}

@Component
class ExternalDeploymentScriptExecutor(
                                        val scriptService: JythonScriptService,
                                        runnerScriptService: RunnerScriptService
                                      ) extends ScriptExecution
  with ExternalDeploymentScriptService
  with Logging {

  @Timed
  @throws(classOf[Exception])
  override def executeScript(connection: StatusWebhookEventSource): AnyRef = {
    logger.debug(s"Executing status script for StatusWebhookEventSource ${connection.getName}")
    if (connection.isInstanceOf[RemoteStatusWebhookEventSource]) {
      runnerScriptService.executeScript[DeploymentServerEvent](
        connection.statusScript,
        buildDefaultInputParams(connection))
    } else {
      execute(createStatusScriptContext(connection))
    }
  }
}

private class StatusScriptContextBuilder(connection: StatusWebhookEventSource) extends BaseScriptContextBuilder(connection) {

  override val scriptProperty: String = StatusScriptProperty

  override protected def doBuild(context: XlrScriptContext): Unit = {
    addConnectionAttributes(context)
    addConnectionServerAttributes(context)
    addScript(context)
  }
}

private object ExternalDeploymentScriptExecutor {
  def createStatusScriptContext(connection: StatusWebhookEventSource): XlrScriptContext = {
    new StatusScriptContextBuilder(connection).build()
  }
}
